#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module Disbursements
            class Disbursement < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'd018ef6c-ee84-488f-bec5-92bf2958ce1a' => OperationConfig.new("/send/#env/v1/partners/{partnerId}/disbursements/{disbursementId}", "read", [], []),
                    '35a14322-0aba-4976-bbd3-9652b9f77c31' => OperationConfig.new("/send/#env/v1/partners/{partnerId}/disbursements", "query", [], ["ref"]),
                    'f12ff652-6ede-43e6-bce5-d3f973b474dc' => OperationConfig.new("/send/#env/v1/partners/{partnerId}/disbursements/payment", "create", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public






                def self.readByID(id, criteria = nil)
                    #
                    #Returns objects of type Disbursement by id and optional criteria
                    #@param [String] id
                    #@param [Dict] criteria
                    #@return [Disbursement] object representing the response
                    #@raise [APIException] an exception from the response status

                    mapObj = Disbursement.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !criteria.nil?
                        if criteria.instance_of? RequestMap
                          mapObj.setAll(criteria.getObject())
                        else
                          mapObj.setAll(criteria)
                        end
                    end

                    return self.execute("d018ef6c-ee84-488f-bec5-92bf2958ce1a",Disbursement.new(mapObj))
                end








                def self.readByReference(criteria)
                    #
                    #Query objects of type Disbursement by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Disbursement] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("35a14322-0aba-4976-bbd3-9652b9f77c31",Disbursement.new(criteria))
                end


                def self.create(mapObj)
                    #
                    #Creates object of type Disbursement
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Disbursement] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("f12ff652-6ede-43e6-bce5-d3f973b474dc", Disbursement.new(mapObj))
                end







            end
        end
    end
end







